Get status of all pods that belong to a job
Source:R/submit_job_k8s.R
abba_get_k8s_job_status_local.RdGet status of all pods that belong to a job
Usage
abba_get_k8s_job_status_local(
job_id,
namespace = getOption("abba.k8s.namespace")
)