Send GET request to get logs of all jobs in a batch
abba_get_batch_log.RdSend GET request to get logs of all jobs in a batch
Usage
abba_get_batch_log(
batch_id,
api_address = Sys.getenv("ABBA_API_ADDRESS"),
api_key = Sys.getenv("ABBA_API_KEY")
)Examples
if (FALSE) { # \dontrun{
response <- abba_get_job_log('1234j-13j4l5k-ajslfd')} # }