Return list of logs for jobs that are marked with a given batch ID
abba_get_k8s_batch_log_local.RdReturn list of logs for jobs that are marked with a given batch ID
Usage
abba_get_k8s_batch_log_local(
batch_id,
namespace = getOption("abba.k8s.namespace")
)