Execute programs via logrx
Source:R/submit_job_workbench.R
abba_rslauncher_submit_logrx_job_local.RdExecute programs via logrx
Arguments
- p
path to program
- log_path
Path to the directory where the log will be saved. Required; must be supplied explicitly so that logs are never written to an unexpected location in the user's filespace.
- user_tag
optional; any user tags user might want to add to the job
- ...
other arguments that will be passed to internal rslauncher_submit_job function