Periodically poll Workbench jobs for status and return their IDs when all job statuses arrive at 'Finished' state
abba_rslauncher_watch_job_local.RdPeriodically poll Workbench jobs for status and return their IDs when all job statuses arrive at 'Finished' state
Usage
abba_rslauncher_watch_job_local(
job_ids,
poll_interval_seconds = 1,
timeout_seconds = 300,
...
)Examples
if (FALSE) { # \dontrun{
job_statuses <- abba_rslauncher_watch_job_local(c('job-id-1', 'job-id-2'))
} # }